@@ -24,7 +24,7 @@ def _importmap(modules_root, package=None, prefix="/statics/vendor"):
     else:
         modules_root = Path(modules_root)
 
-    return scan_packages(modules_root, prefix=prefix).imports
+    return scan_packages(modules_root, prefix=prefix).json(indent=4)
 
 
 class ImportMapExtension(Extension):
